@@ -67,7 +67,6 @@ enum {
 
 static void eel_canvas_re_class_init (EelCanvasREClass *klass);
 static void eel_canvas_re_init       (EelCanvasRE      *re);
-static void eel_canvas_re_destroy    (GtkObject          *object);
 static void eel_canvas_re_set_property (GObject              *object,
 					  guint                 param_id,
 					  const GValue         *value,
@@ -129,11 +128,9 @@ static void
 eel_canvas_re_class_init (EelCanvasREClass *klass)
 {
 	GObjectClass *gobject_class;
-	GtkObjectClass *object_class;
 	EelCanvasItemClass *item_class;
 
 	gobject_class = (GObjectClass *) klass;
-	object_class = (GtkObjectClass *) klass;
 	item_class = (EelCanvasItemClass *) klass;
 
 	re_parent_class = g_type_class_peek_parent (klass);
@@ -219,8 +216,6 @@ eel_canvas_re_class_init (EelCanvasREClass *klass)
 				      0.0, G_MAXDOUBLE, 0.0,
 				      G_PARAM_READWRITE));
 
-	object_class->destroy = eel_canvas_re_destroy;
-
 	item_class->realize = eel_canvas_re_realize;
 	item_class->unrealize = eel_canvas_re_unrealize;
 	item_class->translate = eel_canvas_re_translate;
@@ -237,22 +232,6 @@ eel_canvas_re_init (EelCanvasRE *re)
 	re->width = 0.0;
 }
 
-static void
-eel_canvas_re_destroy (GtkObject *object)
-{
-	EelCanvasRE *re;
-
-	g_return_if_fail (object != NULL);
-	g_return_if_fail (EEL_IS_CANVAS_RE (object));
-
-	re = EEL_CANVAS_RE (object);
-
-	/* remember, destroy can be run multiple times! */
-
-	if (GTK_OBJECT_CLASS (re_parent_class)->destroy)
-		(* GTK_OBJECT_CLASS (re_parent_class)->destroy) (object);
-}
-
 static void get_bounds (EelCanvasRE *re, double *px1, double *py1, double *px2, double *py2)
 {
 	EelCanvasItem *item;
@@ -630,7 +609,7 @@ static void eel_canvas_rect_init (EelCanvasRect *rect);
 static void eel_canvas_rect_finalize (GObject *object);
 static void eel_canvas_rect_realize  (EelCanvasItem *item);
 
-static void   eel_canvas_rect_draw   (EelCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expose);
+static void   eel_canvas_rect_draw   (EelCanvasItem *item, cairo_t *cr, cairo_region_t *region);
 static double eel_canvas_rect_point  (EelCanvasItem *item, double x, double y, int cx, int cy,
 				        EelCanvasItem **actual_item);
 
@@ -751,10 +730,9 @@ eel_canvas_set_source_color (cairo_t *cr,
 #define DASH_ON 0.8
 #define DASH_OFF 1.7
 static void
-eel_canvas_rect_draw (EelCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expose)
+eel_canvas_rect_draw (EelCanvasItem *item, cairo_t *cr, cairo_region_t *region)
 {
 	EelCanvasRE *re;
-        cairo_t *cr;
 	double x1, y1, x2, y2;
 	int cx1, cy1, cx2, cy2;
 	double i2w_dx, i2w_dy;
@@ -777,10 +755,8 @@ eel_canvas_rect_draw (EelCanvasItem *item, GdkDrawable *drawable, GdkEventExpose
 	if (cx2 <= cx1 || cy2 <= cy1 ) {
 		return;
 	}
-	
-	cr = gdk_cairo_create (drawable);
-	gdk_cairo_region (cr, expose->region);
-	cairo_clip (cr);
+
+	cairo_save (cr);
 
 	if (re->fill_set) {
 		eel_canvas_set_source_color (cr, re->fill_color);
@@ -812,7 +788,7 @@ eel_canvas_rect_draw (EelCanvasItem *item, GdkDrawable *drawable, GdkEventExpose
 		cairo_stroke (cr);
 	}
 
-	cairo_destroy (cr);
+	cairo_restore (cr);
 }
 
 static double
@@ -1001,7 +977,7 @@ eel_canvas_rect_update (EelCanvasItem *item, double i2w_dx, double i2w_dy, gint
 
 static void eel_canvas_ellipse_class_init (EelCanvasEllipseClass *klass);
 
-static void   eel_canvas_ellipse_draw   (EelCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expose);
+static void   eel_canvas_ellipse_draw   (EelCanvasItem *item, cairo_t *cr, cairo_region_t *region);
 static double eel_canvas_ellipse_point  (EelCanvasItem *item, double x, double y, int cx, int cy,
 					   EelCanvasItem **actual_item);
 
@@ -1047,12 +1023,11 @@ eel_canvas_ellipse_class_init (EelCanvasEllipseClass *klass)
 }
 
 static void
-eel_canvas_ellipse_draw (EelCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expose)
+eel_canvas_ellipse_draw (EelCanvasItem *item, cairo_t *cr, cairo_region_t *region)
 {
 	EelCanvasRE *re;
 	int x1, y1, x2, y2;
 	double i2w_dx, i2w_dy;
-	cairo_t *cr;
 
 	re = EEL_CANVAS_RE (item);
 
@@ -1071,9 +1046,7 @@ eel_canvas_ellipse_draw (EelCanvasItem *item, GdkDrawable *drawable, GdkEventExp
 			  re->y2 + i2w_dy,
 			  &x2, &y2);
 
-	cr = gdk_cairo_create (drawable);
-	gdk_cairo_region (cr, expose->region);
-	cairo_clip (cr);
+        cairo_save (cr);
 
 	cairo_save (cr);
 	cairo_translate (cr, (x1 + x2) / 2., (y1 + y2) / 2.);
@@ -1097,7 +1070,7 @@ eel_canvas_ellipse_draw (EelCanvasItem *item, GdkDrawable *drawable, GdkEventExp
 		cairo_stroke_preserve (cr);
         }
 
-	cairo_destroy (cr);
+	cairo_restore (cr);
 }
 
 static double
