@@ -30,7 +30,6 @@
 #include "eel-debug.h"
 #include "eel-lib-self-check-functions.h"
 #include "eel-string.h"
-#include "eel-i18n.h"
 #include <glib-object.h>
 #include <math.h>
 #include <stdlib.h>
@@ -702,69 +701,6 @@ eel_round (double d)
 	return val;
 }
 
-GList *
-eel_g_list_from_g_slist (GSList *slist)
-{
-	GList *list;
-	GSList *node;
-
-	list = NULL;
-	for (node = slist; node != NULL; node = node->next) {
-		list = g_list_prepend (list, node->data);
-	}
-	return g_list_reverse (list);
-}
-
-GSList *
-eel_g_slist_from_g_list (GList *list)
-{
-	GSList *slist;
-	GList *node;
-
-	slist = NULL;
-	for (node = list; node != NULL; node = node->next) {
-		slist = g_slist_prepend (slist, node->data);
-	}
-	return g_slist_reverse (slist);
-}
-
-/* Return the operating system name: Linux, Solaris, etc. */
-char *
-eel_get_operating_system_name (void)
-{
-	struct utsname buffer;
-
-	if (uname (&buffer) != -1) {
-		/* Check for special sysnames for which there is 
-		 * more accepted names.
-		 */
-		if (eel_str_is_equal (buffer.sysname, "SunOS")) {
-			return g_strdup ("Solaris");
-		}
-
-		return g_strdup (buffer.sysname);
-	}
-
-	return g_strdup ("Unix");
-}
-
-int
-eel_compare_integer (gconstpointer a,
-			  gconstpointer b)
-{
-	int int_a;
-	int int_b;
-
-	int_a = GPOINTER_TO_INT (a);
-	int_b = GPOINTER_TO_INT (b);
-
-	if (int_a == int_b) {
-		return 0;
-	}
-
-	return int_a < int_b ? -1 : 1;
-}
-
 /**
  * eel_g_object_list_ref
  *
@@ -956,7 +892,7 @@ eel_get_filename_charset (const gchar **filename_charset)
 	  cache->is_utf8 = g_get_charset (&new_charset);
 	  cache->filename_charset = g_strdup (new_charset);
 	}
-      else 
+      else
 	{
 	  cache->filename_charset = g_strdup ("UTF-8");
 	  cache->is_utf8 = TRUE;
@@ -969,9 +905,144 @@ eel_get_filename_charset (const gchar **filename_charset)
   return cache->is_utf8;
 }
 
+static void
+update_auto_boolean (GSettings   *settings,
+		     const gchar *key,
+		     gpointer     user_data)
+{
+	int *storage = user_data;
+
+	*storage = g_settings_get_boolean (settings, key);
+}
+
+void
+eel_g_settings_add_auto_boolean (GSettings *settings,
+				 const char *key,
+				 gboolean *storage)
+{
+	char *signal;
+
+	*storage = g_settings_get_boolean (settings, key);
+	signal = g_strconcat ("changed::", key, NULL);
+	g_signal_connect (settings, signal,
+			  G_CALLBACK(update_auto_boolean),
+			  storage);
+}
+
+static void
+update_auto_int (GSettings   *settings,
+		 const gchar *key,
+		 gpointer     user_data)
+{
+	int *storage = user_data;
+
+	*storage = g_settings_get_int (settings, key);
+}
+
+void
+eel_g_settings_add_auto_int (GSettings *settings,
+			     const char *key,
+			     int *storage)
+{
+	char *signal;
+
+	*storage = g_settings_get_int (settings, key);
+	signal = g_strconcat ("changed::", key, NULL);
+	g_signal_connect (settings, signal,
+			  G_CALLBACK(update_auto_int),
+			  storage);
+}
+
+static void
+update_auto_enum (GSettings   *settings,
+		  const gchar *key,
+		  gpointer     user_data)
+{
+	int *storage = user_data;
+
+	*storage = g_settings_get_enum (settings, key);
+}
+
+void
+eel_g_settings_add_auto_enum (GSettings *settings,
+			      const char *key,
+			      int *storage)
+{
+	char *signal;
+
+	*storage = g_settings_get_enum (settings, key);
+	signal = g_strconcat ("changed::", key, NULL);
+	g_signal_connect (settings, signal,
+			  G_CALLBACK(update_auto_enum),
+			  storage);
+}
+
+static void
+update_auto_strv (GSettings   *settings,
+		  const gchar *key,
+		  gpointer     user_data)
+{
+	char ***storage = user_data;
+
+	g_free (*storage);
+	*storage = g_settings_get_strv (settings, key);
+}
+
+void
+eel_g_settings_add_auto_strv (GSettings *settings,
+			      const char *key,
+			      char ***storage)
+{
+	char *signal;
+
+	*storage = NULL;
+	update_auto_strv (settings, key, storage);
+	signal = g_strconcat ("changed::", key, NULL);
+	g_signal_connect (settings, signal,
+			  G_CALLBACK(update_auto_strv),
+			  storage);
+}
+
+static void
+update_auto_strv_as_quarks (GSettings   *settings,
+			    const gchar *key,
+			    gpointer     user_data)
+{
+	GQuark **storage = user_data;
+	int i = 0;
+	char **value;
+
+	value = g_settings_get_strv (settings, key);
+
+	g_free (*storage);
+	*storage = g_new (GQuark, g_strv_length (value) + 1);
+
+	for (i = 0; value[i] != NULL; ++i) {
+		(*storage)[i] = g_quark_from_string (value[i]);
+	}
+	(*storage)[i] = 0;
+
+	g_strfreev (value);
+}
+
+void
+eel_g_settings_add_auto_strv_as_quarks (GSettings *settings,
+					const char *key,
+					GQuark **storage)
+{
+	char *signal;
+
+	*storage = NULL;
+	update_auto_strv_as_quarks (settings, key, storage);
+	signal = g_strconcat ("changed::", key, NULL);
+	g_signal_connect (settings, signal,
+			  G_CALLBACK(update_auto_strv_as_quarks),
+			  storage);
+}
+
 #if !defined (EEL_OMIT_SELF_CHECK)
 
-static void 
+static void
 check_tm_to_g_date (time_t time)
 {
 	struct tm *before_conversion;
@@ -1150,27 +1221,6 @@ eel_self_check_glib_extensions (void)
 	setlocale (LC_TIME, "");
 
 	g_free (huge_string);
-
-	/* eel_shell_quote */
-	EEL_CHECK_STRING_RESULT (g_shell_quote (""), "''");
-	EEL_CHECK_STRING_RESULT (g_shell_quote ("a"), "'a'");
-	EEL_CHECK_STRING_RESULT (g_shell_quote ("("), "'('");
-	EEL_CHECK_STRING_RESULT (g_shell_quote ("'"), "''\\'''");
-	EEL_CHECK_STRING_RESULT (g_shell_quote ("'a"), "''\\''a'");
-	EEL_CHECK_STRING_RESULT (g_shell_quote ("a'"), "'a'\\'''");
-	EEL_CHECK_STRING_RESULT (g_shell_quote ("a'a"), "'a'\\''a'");
-
-	/* eel_compare_integer */
-	EEL_CHECK_INTEGER_RESULT (eel_compare_integer (GINT_TO_POINTER (0), GINT_TO_POINTER (0)), 0);
-	EEL_CHECK_INTEGER_RESULT (eel_compare_integer (GINT_TO_POINTER (0), GINT_TO_POINTER (1)), -1);
-	EEL_CHECK_INTEGER_RESULT (eel_compare_integer (GINT_TO_POINTER (1), GINT_TO_POINTER (0)), 1);
-	EEL_CHECK_INTEGER_RESULT (eel_compare_integer (GINT_TO_POINTER (-1), GINT_TO_POINTER (0)), -1);
-	EEL_CHECK_INTEGER_RESULT (eel_compare_integer (GINT_TO_POINTER (0), GINT_TO_POINTER (-1)), 1);
-	EEL_CHECK_INTEGER_RESULT (eel_compare_integer (GINT_TO_POINTER (-1), GINT_TO_POINTER (-1)), 0);
-
-#ifdef __linux__
-	EEL_CHECK_STRING_RESULT (eel_get_operating_system_name (), "Linux");
-#endif
 }
 
 #endif /* !EEL_OMIT_SELF_CHECK */
