@@ -259,7 +259,7 @@ dialog_response_cb (GtkDialog *dialog,
 }
 
 static void
-dialog_destroy_cb (GtkObject *object,
+dialog_destroy_cb (GtkWidget *object,
                    NautilusAutorunComboBoxData *data)
 {
 	handle_dialog_closure (data);
@@ -693,8 +693,9 @@ is_shift_pressed (void)
 	ret = FALSE;
 
         gdk_error_trap_push ();
-	status = XkbGetState (GDK_DISPLAY (), XkbUseCoreKbd, &state);
-        gdk_error_trap_pop ();
+	status = XkbGetState (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()),
+			      XkbUseCoreKbd, &state);
+        gdk_error_trap_pop_ignored ();
 
 	if (status == Success) {
 		ret = state.mods & ShiftMask;
@@ -841,7 +842,7 @@ autorun_always_toggled (GtkToggleButton *togglebutton, AutorunDialogData *data)
 static gboolean
 combo_box_enter_ok (GtkWidget *togglebutton, GdkEventKey *event, GtkDialog *dialog)
 {
-	if (event->keyval == GDK_KP_Enter || event->keyval == GDK_Return) {
+	if (event->keyval == GDK_KEY_KP_Enter || event->keyval == GDK_KEY_Return) {
 		gtk_dialog_response (dialog, GTK_RESPONSE_OK);
 		return TRUE;
 	}
@@ -919,7 +920,6 @@ show_dialog:
 
 	dialog = gtk_dialog_new ();
 
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), hbox, TRUE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 12);
