@@ -34,12 +34,10 @@
 #define NAUTILUS_ICON_DND_GNOME_ICON_LIST_TYPE	"x-special/gnome-icon-list"
 #define NAUTILUS_ICON_DND_URI_LIST_TYPE		"text/uri-list"
 #define NAUTILUS_ICON_DND_NETSCAPE_URL_TYPE	"_NETSCAPE_URL"
-#define NAUTILUS_ICON_DND_COLOR_TYPE		"application/x-color"
 #define NAUTILUS_ICON_DND_BGIMAGE_TYPE		"property/bgimage"
-#define NAUTILUS_ICON_DND_KEYWORD_TYPE		"property/keyword"
-#define NAUTILUS_ICON_DND_RESET_BACKGROUND_TYPE "x-special/gnome-reset-background"
 #define NAUTILUS_ICON_DND_ROOTWINDOW_DROP_TYPE	"application/x-rootwindow-drop"
 #define NAUTILUS_ICON_DND_XDNDDIRECTSAVE_TYPE	"XdndDirectSave0" /* XDS Protocol Type */
+#define NAUTILUS_ICON_DND_RAW_TYPE	"application/octet-stream"
 
 /* Item of the drag selection list */
 typedef struct {
@@ -54,12 +52,9 @@ typedef enum {
 	NAUTILUS_ICON_DND_GNOME_ICON_LIST,
 	NAUTILUS_ICON_DND_URI_LIST,
 	NAUTILUS_ICON_DND_NETSCAPE_URL,
-	NAUTILUS_ICON_DND_COLOR,
-	NAUTILUS_ICON_DND_BGIMAGE,
-	NAUTILUS_ICON_DND_KEYWORD,
 	NAUTILUS_ICON_DND_TEXT,
-	NAUTILUS_ICON_DND_RESET_BACKGROUND,
 	NAUTILUS_ICON_DND_XDNDDIRECTSAVE,
+	NAUTILUS_ICON_DND_RAW,
 	NAUTILUS_ICON_DND_ROOTWINDOW_DROP
 } NautilusIconDndTargetType;
 
@@ -171,8 +166,6 @@ int			    nautilus_drag_modifier_based_action		(int				       default_action,
 
 GdkDragAction		    nautilus_drag_drop_action_ask		(GtkWidget			      *widget,
 									 GdkDragAction			       possible_actions);
-GdkDragAction		    nautilus_drag_drop_background_ask		(GtkWidget			      *widget,
-									 GdkDragAction			       possible_actions);
 
 gboolean		    nautilus_drag_autoscroll_in_scroll_region	(GtkWidget			      *widget);
 void			    nautilus_drag_autoscroll_calculate_delta	(GtkWidget			      *widget,
