@@ -30,8 +30,8 @@
 #include "nautilus-directory-notify.h"
 #include "nautilus-file.h"
 #include <eel/eel-glib-extensions.h>
+#include <eel/eel-gtk-macros.h>
 #include <gtk/gtk.h>
-#include <libgnome/gnome-macros.h>
 
 struct NautilusMergedDirectoryDetails {
 	GList *directories;
@@ -56,7 +56,6 @@ typedef struct {
 	NautilusMergedDirectory *merged;
 
 	gboolean monitor_hidden_files;
-	gboolean monitor_backup_files;
 	NautilusFileAttributes monitor_attributes;
 } MergedMonitor;
 
@@ -68,8 +67,9 @@ enum {
 
 static guint signals[LAST_SIGNAL];
 
-GNOME_CLASS_BOILERPLATE (NautilusMergedDirectory, nautilus_merged_directory,
-			 NautilusDirectory, NAUTILUS_TYPE_DIRECTORY)
+G_DEFINE_TYPE (NautilusMergedDirectory, nautilus_merged_directory,
+	       NAUTILUS_TYPE_DIRECTORY);
+#define parent_class nautilus_merged_directory_parent_class
 
 static guint
 merged_callback_hash (gconstpointer merged_callback_as_pointer)
@@ -256,7 +256,6 @@ static void
 merged_monitor_add (NautilusDirectory *directory,
 		    gconstpointer client,
 		    gboolean monitor_hidden_files,
-		    gboolean monitor_backup_files,
 		    NautilusFileAttributes file_attributes,
 		    NautilusDirectoryCallback callback,
 		    gpointer callback_data)
@@ -281,15 +280,14 @@ merged_monitor_add (NautilusDirectory *directory,
 				     (gpointer) client, monitor);
 	}
 	monitor->monitor_hidden_files = monitor_hidden_files;
-	monitor->monitor_backup_files = monitor_backup_files;
 	monitor->monitor_attributes = file_attributes;
-	
+
 	/* Call through to the real directory add calls. */
 	merged_callback_list = NULL;
 	for (node = merged->details->directories; node != NULL; node = node->next) {
 		nautilus_directory_file_monitor_add
 			(node->data, monitor,
-			 monitor_hidden_files, monitor_backup_files,
+			 monitor_hidden_files,
 			 file_attributes,
 			 build_merged_callback_list, &merged_callback_list);
 	}
@@ -401,7 +399,7 @@ merged_is_not_empty (NautilusDirectory *directory)
 static GList *
 merged_get_file_list (NautilusDirectory *directory)
 {
-	GList *dirs_file_list, *merged_dir_file_list;
+	GList *dirs_file_list, *merged_dir_file_list = NULL;
 	GList *dir_list;
 	GList *cur_node;
 
@@ -416,8 +414,8 @@ merged_get_file_list (NautilusDirectory *directory)
 						 nautilus_directory_get_file_list (cur_dir));
 	}
 
-	merged_dir_file_list = GNOME_CALL_PARENT_WITH_DEFAULT
-				(NAUTILUS_DIRECTORY_CLASS, get_file_list, (directory), NULL);
+	merged_dir_file_list = EEL_CALL_PARENT_WITH_RETURN_VALUE
+				(NAUTILUS_DIRECTORY_CLASS, get_file_list, (directory));
 
 	return g_list_concat (dirs_file_list, merged_dir_file_list);
 }
@@ -460,7 +458,6 @@ monitor_add_directory (gpointer key,
 	nautilus_directory_file_monitor_add
 		(NAUTILUS_DIRECTORY (callback_data), monitor,
 		 monitor->monitor_hidden_files,
-		 monitor->monitor_backup_files,
 		 monitor->monitor_attributes,
 		 forward_files_added_cover, monitor->merged);
 }
@@ -649,7 +646,7 @@ merged_finalize (GObject *object)
 }
 
 static void
-nautilus_merged_directory_instance_init (NautilusMergedDirectory *merged)
+nautilus_merged_directory_init (NautilusMergedDirectory *merged)
 {
 	merged->details = g_new0 (NautilusMergedDirectoryDetails, 1);
 	merged->details->callbacks = g_hash_table_new
