@@ -27,7 +27,6 @@
 
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-stock-dialogs.h>
-#include <eel/eel-alert-dialog.h>
 #include <eel/eel-string.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
@@ -730,7 +729,7 @@ report_broken_symbolic_link (GtkWindow *parent_window, NautilusFile *file)
 	 */
 
 	response = gtk_dialog_run (dialog);
-	gtk_object_destroy (GTK_OBJECT (dialog));
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 
 	if (response == GTK_RESPONSE_YES) {
 		file_as_list.data = file;
@@ -757,8 +756,8 @@ get_executable_text_file_action (GtkWindow *parent_window, NautilusFile *file)
 
 	g_assert (nautilus_file_contains_text (file));
 
-	preferences_value = eel_preferences_get_enum 
-		(NAUTILUS_PREFERENCES_EXECUTABLE_TEXT_ACTIVATION);
+	preferences_value = g_settings_get_enum	(nautilus_preferences,
+						 NAUTILUS_PREFERENCES_EXECUTABLE_TEXT_ACTIVATION);
 	switch (preferences_value) {
 	case NAUTILUS_EXECUTABLE_TEXT_LAUNCH:
 		return ACTIVATION_ACTION_LAUNCH;
@@ -795,7 +794,7 @@ get_executable_text_file_action (GtkWindow *parent_window, NautilusFile *file)
 	g_free (detail);
 
 	response = gtk_dialog_run (dialog);
-	gtk_object_destroy (GTK_OBJECT (dialog));
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 	
 	switch (response) {
 	case RESPONSE_RUN:
@@ -814,8 +813,8 @@ get_default_executable_text_file_action (void)
 {
 	int preferences_value;
 
-	preferences_value = eel_preferences_get_enum 
-		(NAUTILUS_PREFERENCES_EXECUTABLE_TEXT_ACTIVATION);
+	preferences_value = g_settings_get_enum	(nautilus_preferences,
+						 NAUTILUS_PREFERENCES_EXECUTABLE_TEXT_ACTIVATION);
 	switch (preferences_value) {
 	case NAUTILUS_EXECUTABLE_TEXT_LAUNCH:
 		return ACTIVATION_ACTION_LAUNCH;
@@ -1125,7 +1124,7 @@ confirm_multiple_windows (GtkWindow *parent_window,
 	g_free (detail);
 
 	response = gtk_dialog_run (dialog);
-	gtk_object_destroy (GTK_OBJECT (dialog));
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 
 	return response == GTK_RESPONSE_YES;
 }
@@ -1153,11 +1152,15 @@ activate_parameters_install_free (ActivateParametersInstall *parameters_install)
 	if (parameters_install->parent_window) {
 		g_object_remove_weak_pointer (G_OBJECT (parameters_install->parent_window), (gpointer *)&parameters_install->parent_window);
 	}
+
+	if (parameters_install->proxy != NULL) {
+	        g_object_unref (parameters_install->proxy);
+	}
+
 	nautilus_file_unref (parameters_install->file);
 	nautilus_file_list_free (parameters_install->files);
 	g_free (parameters_install->activation_directory);
 	g_free (parameters_install->uri);
-        g_object_unref (parameters_install->proxy);
 	g_free (parameters_install);
 }
 
@@ -1262,22 +1265,28 @@ show_unhandled_type_error (ActivateParametersInstall *parameters)
 	char *mime_type = nautilus_file_get_mime_type (parameters->file);
 	char *error_message = get_application_no_mime_type_handler_message (parameters->file, parameters->uri);
 	if (g_content_type_is_unknown (mime_type)) {
-		dialog = eel_alert_dialog_new (parameters->parent_window,
-		                      GTK_DIALOG_DESTROY_WITH_PARENT,
-                		      GTK_MESSAGE_ERROR,
-		                      0,
-                		      error_message,
-                		      _("The file is of an unknown type"));
+		dialog = gtk_message_dialog_new (parameters->parent_window,
+						 GTK_DIALOG_DESTROY_WITH_PARENT,
+						 GTK_MESSAGE_ERROR,
+						 0,
+						 NULL);
+		g_object_set (dialog,
+			      "text", error_message,
+			      "secondary-text", _("The file is of an unknown type"),
+			      NULL);
 	} else {
 		char *text;
 		text = g_strdup_printf (_("There is no application installed for %s files"), g_content_type_get_description (mime_type));
 
-		dialog = eel_alert_dialog_new (parameters->parent_window,
-		                      GTK_DIALOG_DESTROY_WITH_PARENT,
-                		      GTK_MESSAGE_ERROR,
-		                      0,
-                		      error_message,
-                		      text);
+		dialog = gtk_message_dialog_new (parameters->parent_window,
+						 GTK_DIALOG_DESTROY_WITH_PARENT,
+						 GTK_MESSAGE_ERROR,
+						 0,
+						 NULL);
+		g_object_set (dialog,
+			      "text", error_message,
+			      "secondary-text", text,
+			      NULL);
 
 		g_free (text);
 	}
@@ -1488,7 +1497,7 @@ application_unhandled_uri (ActivateParameters *parameters, char *uri)
 
 #ifdef ENABLE_PACKAGEKIT
 	/* allow an admin to disable the PackageKit search functionality */
-	show_install_mime = eel_preferences_get_boolean (NAUTILUS_PREFERENCES_INSTALL_MIME_ACTIVATION);
+	show_install_mime = g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_INSTALL_MIME_ACTIVATION);
 #else
 	/* we have no install functionality */
 	show_install_mime = FALSE;
@@ -1605,12 +1614,15 @@ activate_desktop_file (ActivateParameters *parameters,
 					   ),
 					 display_name);
 		
-		dialog = eel_alert_dialog_new (parameters->parent_window,
-					       0,
-					       GTK_MESSAGE_WARNING,
-					       GTK_BUTTONS_NONE,
-					       primary,
-					       secondary);
+		dialog = gtk_message_dialog_new (parameters->parent_window,
+						 0,
+						 GTK_MESSAGE_WARNING,
+						 GTK_BUTTONS_NONE,
+						 NULL);
+		g_object_set (dialog,
+			      "text", primary,
+			      "secondary-text", secondary,
+			      NULL);
 		gtk_dialog_add_button (GTK_DIALOG (dialog),
 				       _("_Launch Anyway"), RESPONSE_RUN);
 		if (nautilus_file_can_set_permissions (file)) {
@@ -1796,7 +1808,7 @@ activate_files (ActivateParameters *parameters)
 				       (flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB) != 0))) {
 
 		if ((flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB) != 0 &&
-		    eel_preferences_get_enum (NAUTILUS_PREFERENCES_NEW_TAB_POSITION) ==
+		    g_settings_get_enum (nautilus_preferences, NAUTILUS_PREFERENCES_NEW_TAB_POSITION) ==
 		    NAUTILUS_NEW_TAB_POSITION_AFTER_CURRENT_TAB) {
 			/* When inserting N tabs after the current one,
 			 * we first open tab N, then tab N-1, ..., then tab 0.
@@ -1837,7 +1849,9 @@ activate_files (ActivateParameters *parameters)
 	num_files = g_list_length (open_in_app_uris);
 	open_files = TRUE;
 
-	if (!parameters->user_confirmation || num_files + num_unhandled > SILENT_OPEN_LIMIT) {
+	if (open_in_app_uris != NULL &&
+	    (!parameters->user_confirmation ||
+	     num_files + num_unhandled > SILENT_OPEN_LIMIT)) {
 		GtkDialog *dialog;
 		char *prompt;
 		char *detail;
