@@ -28,39 +28,43 @@
 #ifndef NAUTILUS_BOOKMARK_LIST_H
 #define NAUTILUS_BOOKMARK_LIST_H
 
-#include <libnautilus-extensions/nautilus-bookmark.h>
+#include <libnautilus-private/nautilus-bookmark.h>
+#include <gio/gio.h>
 
 typedef struct NautilusBookmarkList NautilusBookmarkList;
 typedef struct NautilusBookmarkListClass NautilusBookmarkListClass;
 
-#define NAUTILUS_TYPE_BOOKMARK_LIST \
-	(nautilus_bookmark_list_get_type ())
+#define NAUTILUS_TYPE_BOOKMARK_LIST nautilus_bookmark_list_get_type()
 #define NAUTILUS_BOOKMARK_LIST(obj) \
-	(GTK_CHECK_CAST ((obj), NAUTILUS_TYPE_BOOKMARK_LIST, NautilusBookmarkList))
+  (G_TYPE_CHECK_INSTANCE_CAST ((obj), NAUTILUS_TYPE_BOOKMARK_LIST, NautilusBookmarkList))
 #define NAUTILUS_BOOKMARK_LIST_CLASS(klass) \
-	(GTK_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_BOOKMARK_LIST, NautilusBookmarkListClass))
+  (G_TYPE_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_BOOKMARK_LIST, NautilusBookmarkListClass))
 #define NAUTILUS_IS_BOOKMARK_LIST(obj) \
-	(GTK_CHECK_TYPE ((obj), NAUTILUS_TYPE_BOOKMARK_LIST))
+  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NAUTILUS_TYPE_BOOKMARK_LIST))
 #define NAUTILUS_IS_BOOKMARK_LIST_CLASS(klass) \
-	(GTK_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_BOOKMARK_LIST))
+  (G_TYPE_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_BOOKMARK_LIST))
+#define NAUTILUS_BOOKMARK_LIST_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), NAUTILUS_TYPE_BOOKMARK_LIST, NautilusBookmarkListClass))
 
 struct NautilusBookmarkList {
-	GtkObject object;
-	GList *list;
+	GObject object;
+
+	GList *list; 
+	GFileMonitor *monitor;
+	GQueue *pending_ops;
 };
 
 struct NautilusBookmarkListClass {
-	GtkObjectClass parent_class;
+	GObjectClass parent_class;
 	void (* contents_changed) (NautilusBookmarkList *bookmarks);
 };
 
-GtkType                 nautilus_bookmark_list_get_type            (void);
+GType                   nautilus_bookmark_list_get_type            (void);
 NautilusBookmarkList *  nautilus_bookmark_list_new                 (void);
 void                    nautilus_bookmark_list_append              (NautilusBookmarkList   *bookmarks,
 								    NautilusBookmark *bookmark);
 gboolean                nautilus_bookmark_list_contains            (NautilusBookmarkList   *bookmarks,
 								    NautilusBookmark *bookmark);
-void                    nautilus_bookmark_list_contents_changed    (NautilusBookmarkList   *bookmarks);
 void                    nautilus_bookmark_list_delete_item_at      (NautilusBookmarkList   *bookmarks,
 								    guint                   index);
 void                    nautilus_bookmark_list_delete_items_with_uri (NautilusBookmarkList *bookmarks,
@@ -71,6 +75,9 @@ void                    nautilus_bookmark_list_insert_item         (NautilusBook
 guint                   nautilus_bookmark_list_length              (NautilusBookmarkList   *bookmarks);
 NautilusBookmark *      nautilus_bookmark_list_item_at             (NautilusBookmarkList   *bookmarks,
 								    guint                   index);
+void                    nautilus_bookmark_list_move_item           (NautilusBookmarkList *bookmarks,
+								    guint                 index,
+								    guint                 destination);
 void                    nautilus_bookmark_list_set_window_geometry (NautilusBookmarkList   *bookmarks,
 								    const char             *geometry);
 const char *            nautilus_bookmark_list_get_window_geometry (NautilusBookmarkList   *bookmarks);
